Isosurface — PyProcar 6.2.1 documentation

Skip to main content
`Ctrl`+`K`

# Isosurface

The `pyprocar.core.Isosurface` is used to generate an isosurface for an isovalue from a numpy array of coordinate points and a a 1d numpy array of scalar values. This class is an extension of the `pyprocar.core.Surface` class.

`pyprocar.core.Isosurface`(*args, **kwargs) | This class contains a surface that finds all the points corresponding to the following equation.